Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mcp230xx_simpletest.py
    :caption: examples/mcp230xx_simpletest.py
    :linenos:

MCP23Sxx Simple test
---------------------

Simple demo of reading and writing the digital I/O of the MCP2300xx as if
they were native CircuitPython digital inputs/outputs.

.. literalinclude:: ../examples/mcp23Sxx_simpletest.py
    :caption: examples/mcp23Sxx_simpletest.py
    :linenos:

MCP230xx Event detect interrupt
-------------------------------

Example showing the event detect interrupt feature


.. literalinclude:: ../examples/mcp230xx_event_detect_interrupt.py
    :caption: examples/mcp230xx_event_detect_interrupt.py
    :linenos:

MCP23Sxx Event detect interrupt
-------------------------------

Example showing the event detect interrupt feature


.. literalinclude:: ../examples/mcp23Sxx_event_detect_interrupt.py
    :caption: examples/mcp23Sxx_event_detect_interrupt.py
    :linenos:

MCP230xx LEDs and Buttons
-------------------------------

LEDs and buttons example for the MCP230xx

.. literalinclude:: ../examples/mcp230xx_leds_and_buttons.py
    :caption: examples/mcp230xx_leds_and_buttons.py
    :linenos:

MCP23Sxx LEDs and Buttons
-----------------------------

LEDs and buttons example for the MCP23Sxx

.. literalinclude:: ../examples/mcp230xx_leds_and_buttons_irq.py
    :caption: examples/mcp230xx_leds_and_buttons_irq.py
    :linenos:
